==> zio-aws-codeartifact_3-5.17.124.3-sources.jar: zio/aws/codeartifact/model/GetRepositoryPermissionsPolicyRequest.scala <==
package zio.aws.codeartifact.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.codeartifact.model.primitives.{
  RepositoryName,
  AccountId,
  DomainName
}
import scala.jdk.CollectionConverters.*
final case class GetRepositoryPermissionsPolicyRequest(
    domain: DomainName,
    domainOwner: Option[AccountId] = None,
    repository: RepositoryName
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codeartifact.model.GetRepositoryPermissionsPolicyRequest = {
    import GetRepositoryPermissionsPolicyRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codeartifact.model.GetRepositoryPermissionsPolicyRequest
      .builder()
      .domain(DomainName.unwrap(domain): java.lang.String)
      .optionallyWith(
        domainOwner.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.domainOwner)
      .repository(RepositoryName.unwrap(repository): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.codeartifact.model.GetRepositoryPermissionsPolicyRequest.ReadOnly =
    zio.aws.codeartifact.model.GetRepositoryPermissionsPolicyRequest
      .wrap(buildAwsValue())
}
object GetRepositoryPermissionsPolicyRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codeartifact.model.GetRepositoryPermissionsPolicyRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.codeartifact.model.GetRepositoryPermissionsPolicyRequest =
      zio.aws.codeartifact.model.GetRepositoryPermissionsPolicyRequest(
        domain,
        domainOwner.map(value => value),
        repository
      )
    def domain: DomainName
    def domainOwner: Option[AccountId]
    def repository: RepositoryName
    def getDomain: ZIO[Any, Nothing, DomainName] = ZIO.succeed(domain)
    def getDomainOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("domainOwner", domainOwner)
    def getRepository: ZIO[Any, Nothing, RepositoryName] =
      ZIO.succeed(repository)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codeartifact.model.GetRepositoryPermissionsPolicyRequest
  ) extends zio.aws.codeartifact.model.GetRepositoryPermissionsPolicyRequest.ReadOnly {
    override val domain: DomainName =
      zio.aws.codeartifact.model.primitives.DomainName(impl.domain())
    override val domainOwner: Option[AccountId] = scala
      .Option(impl.domainOwner())
      .map(value => zio.aws.codeartifact.model.primitives.AccountId(value))
    override val repository: RepositoryName =
      zio.aws.codeartifact.model.primitives.RepositoryName(impl.repository())
  }
  def wrap(
      impl: software.amazon.awssdk.services.codeartifact.model.GetRepositoryPermissionsPolicyRequest
  ): zio.aws.codeartifact.model.GetRepositoryPermissionsPolicyRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-codeartifact_3-5.17.195.3-sources.jar: zio/aws/codeartifact/model/GetRepositoryPermissionsPolicyRequest.scala <==
package zio.aws.codeartifact.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.codeartifact.model.primitives.{
  RepositoryName,
  AccountId,
  DomainName
}
import scala.jdk.CollectionConverters.*
final case class GetRepositoryPermissionsPolicyRequest(
    domain: DomainName,
    domainOwner: Optional[AccountId] = Optional.Absent,
    repository: RepositoryName
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codeartifact.model.GetRepositoryPermissionsPolicyRequest = {
    import GetRepositoryPermissionsPolicyRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codeartifact.model.GetRepositoryPermissionsPolicyRequest
      .builder()
      .domain(DomainName.unwrap(domain): java.lang.String)
      .optionallyWith(
        domainOwner.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.domainOwner)
      .repository(RepositoryName.unwrap(repository): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.codeartifact.model.GetRepositoryPermissionsPolicyRequest.ReadOnly =
    zio.aws.codeartifact.model.GetRepositoryPermissionsPolicyRequest
      .wrap(buildAwsValue())
}
object GetRepositoryPermissionsPolicyRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codeartifact.model.GetRepositoryPermissionsPolicyRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.codeartifact.model.GetRepositoryPermissionsPolicyRequest =
      zio.aws.codeartifact.model.GetRepositoryPermissionsPolicyRequest(
        domain,
        domainOwner.map(value => value),
        repository
      )
    def domain: DomainName
    def domainOwner: Optional[AccountId]
    def repository: RepositoryName
    def getDomain: ZIO[Any, Nothing, DomainName] = ZIO.succeed(domain)
    def getDomainOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("domainOwner", domainOwner)
    def getRepository: ZIO[Any, Nothing, RepositoryName] =
      ZIO.succeed(repository)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codeartifact.model.GetRepositoryPermissionsPolicyRequest
  ) extends zio.aws.codeartifact.model.GetRepositoryPermissionsPolicyRequest.ReadOnly {
    override val domain: DomainName =
      zio.aws.codeartifact.model.primitives.DomainName(impl.domain())
    override val domainOwner: Optional[AccountId] = zio.aws.core.internal
      .optionalFromNullable(impl.domainOwner())
      .map(value => zio.aws.codeartifact.model.primitives.AccountId(value))
    override val repository: RepositoryName =
      zio.aws.codeartifact.model.primitives.RepositoryName(impl.repository())
  }
  def wrap(
      impl: software.amazon.awssdk.services.codeartifact.model.GetRepositoryPermissionsPolicyRequest
  ): zio.aws.codeartifact.model.GetRepositoryPermissionsPolicyRequest.ReadOnly =
    new Wrapper(impl)
}
